@@ -1,10 +1,12 @@
 #ifndef DBDIMP_H
 #define DBDIMP_H
 /*
-   $Id: Ingres.sh,v 1.2 1996/12/02 12:54:18 ht Exp $
+   $Id: Ingres.sh,v 1.4 1997/01/10 14:40:39 ht Exp $
 
    Copyright (c) 1994,1995  Tim Bunce
-
+   Copyright (c) 1996,1997  Henrik Tougaard (ht@datani.dk)
+   				Ingres modifications
+   
    You may distribute under the terms of either the GNU General Public
    License or the Artistic License, as specified in the Perl README file.
 
@@ -26,30 +28,23 @@ struct imp_drh_st {
 /* Define dbh implementor data structure */
 struct imp_dbh_st {
     dbih_dbc_t com;         /* MUST be first element in structure   */
+    int        session;     /* session id for this connection */
 };
 
-typedef struct {
-    int is_open;
-} cursor;
-
 /* Define sth implementor data structure */
 struct imp_sth_st {
     dbih_stc_t com;         /* MUST be first element in structure   */
 
-    imp_dbh_t *imp_dbh;
-
-    int cursoridx;          /* number of cursor to use, -1 if non-cursor statement */
-    IISQLDA sqlda;
-    int row_num;
-
+    IISQLDA sqlda;          /* descriptor for statement (select) */
     char      *name;        /* statement name!!! */
+    int        st_num;      /* statement number */
     int        done_desc;   /* have we described this sth yet ?	*/
     int        fbh_num;     /* number of output fields		*/
-    imp_fbh_t *fbh;	        /* array of imp_fbh_t structs	*/
+    imp_fbh_t *fbh;	    /* array of imp_fbh_t structs	*/
 };
 
-struct imp_fbh_st { 	/* field buffer EXPERIMENTAL */
-    imp_sth_t *imp_sth;	/* 'parent' statement */
+struct imp_fbh_st { 	    /* field buffer EXPERIMENTAL */
+    imp_sth_t *imp_sth;	    /* 'parent' statement */
 
     /* Ingres description of the field	*/
     IISQLVAR*   var;        /* pointer to Ingres description */
@@ -66,7 +61,7 @@ struct imp_fbh_st { 	/* field buffer EXPERIMENTAL */
         int *   iv;
         double* nv;
         char*   pv;
-    } var_ptr;
+    } var_ptr;              /* buffer for data */
 };
 
 
